@@ -7,10 +7,13 @@ runPC <- function(X, parentsOf, alpha, variableSelMat, setOptions, directed, ver
   }
   
   # additional options for PC
-  optionsList <- list("indepTest"=pcalg::gaussCItest, "fixedEdges"=NULL,
+  optionsList <- list("indepTest"=pcalg::gaussCItest, 
+                      "labels"=as.character(1:ncol(X)),
+                      "fixedEdges"=NULL,
                       "NAdelete"=TRUE, "m.max"=Inf, "u2pd" = "relaxed", 
                       "skel.method"= "stable", "conservative"=FALSE,
-                      "maj.rule"=FALSE, "solve.confl"=FALSE)
+                      "maj.rule"=FALSE, "solve.confl"=FALSE,
+                      "numCores"=1)
   
   # adjust according to setOptions if necessary
   optionsList <- adjustOptions(availableOptions = optionsList, 
@@ -25,13 +28,16 @@ runPC <- function(X, parentsOf, alpha, variableSelMat, setOptions, directed, ver
   pc.fit <- pcalg::pc(suffStat = suffStat, 
                       indepTest = optionsList$indepTest, p=ncol(X), 
                alpha = alpha, 
+               labels=optionsList$labels,
                fixedGaps= if(is.null(variableSelMat)) NULL else (!variableSelMat), 
                fixedEdges = optionsList$fixedEdges, 
                NAdelete= optionsList$NAdelete, m.max= optionsList$m.max, 
-               u2pd=optionsList$u2pd, skel.method= optionsList$skel.method, 
+               u2pd=optionsList$u2pd, 
+               skel.method= optionsList$skel.method, 
                conservative= optionsList$conservative, 
                maj.rule= optionsList$maj.rule, 
                solve.confl = optionsList$solve.confl, 
+               numCores=optionsList$numCores,
                verbose= verbose)
   pcmat <- as(pc.fit@graph, "matrix") 
   if(directed){
